File Handling
=============

File abstractions, registries, and format-specific handlers for ETLPlus file
connectors.

See also: :doc:`../guides/file-handler-matrix`

.. autosummary::
   :toctree: generated

   etlplus.file.base
   etlplus.file.core
   etlplus.file.enums

.. toctree::
   :maxdepth: 1

   file-delimited
   file-semi-structured
   file-columnar
   file-binary
   file-databases
   file-spreadsheets
   file-scientific
   file-wrappers
